# De:func
:construction: Small package for De:code functions under development

## Installation

```
$ pip install defunc
```

Note that Python 3.6 or higher version is required.

## Dependent packages

+ decode
+ numpy
+ scipy
+ xarray
+ pandas
+ astropy
+ scikit-learn
+ tqdm